package cd.casic.module.machine.controller;


import cd.casic.module.machine.service.MachineEnvService;
import cd.casic.module.machine.dto.MachineEnvDTO;
import cd.casic.module.machine.pojo.ResponseData;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;
import java.util.List;


/**
 * 环境变量控制器
 */
@RestController
@RequestMapping("/api/machineEnv")
@Tag(name = "环境变量管理")
@RequiredArgsConstructor
public class MachineEnvController {

    @Resource
    private MachineEnvService machineEnvService;

    @PostMapping("/add")
    @Operation(summary = "新增环境变量")
    public ResponseData add(@RequestBody MachineEnvDTO machineEnvDTO) {
        return machineEnvService.add(machineEnvDTO) ? ResponseData.success() : ResponseData.error("新增机器的环境变量失败");
    }

    @PutMapping("/update")
    @Operation(summary = "修改环境变量")
    public ResponseData update(@RequestBody MachineEnvDTO machineEnvDTO) {
        return machineEnvService.update(machineEnvDTO) ? ResponseData.success() : ResponseData.error("修改环境变量失败");
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除机器的环境变量")
    public ResponseData deleteByMachineId(
            @RequestParam Long machineId) {
        machineEnvService.deleteByMachineId(machineId);
        return ResponseData.success();
    }

    @DeleteMapping("/deleteList")
    @Operation(summary = "批量删除机器环境变量")
    public ResponseData deleteList(@RequestParam List<Long> ids){
        machineEnvService.deleteList(ids);
        return ResponseData.success();
    }

    @GetMapping("/listByMachineId")
    @Operation(summary = "获取机器的环境变量")
    public ResponseData getByMachineId(
            @RequestParam Long machineId) {
        return ResponseData.success(machineEnvService.getByMachineId(machineId));
    }


    @PostMapping("/list")
    @Operation(summary ="获取环境变量列表")
    public ResponseData list(@RequestBody MachineEnvDTO machineEnvDTO) {
        return ResponseData.success(machineEnvService.listEnv(machineEnvDTO));
    }
}
