package cd.casic.module.machine.controller;


import cd.casic.module.machine.entity.MachineInfo;
import cd.casic.module.machine.service.MachineInfoService;
import cd.casic.module.machine.dto.MachineInfoDto;
import cd.casic.module.machine.pojo.ResponseData;
import cd.casic.module.machine.pojo.SuccessResponseData;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@Tag(name = "机器信息管理")
@RequestMapping("/api/machineInfo")
public class MachineInfoController {
    @Resource
    private MachineInfoService machineInfoService;

    @PostMapping("/add")
    @Operation(summary = "新增机器信息")
    public ResponseData add(@RequestBody MachineInfoDto machineInfoDto) {
        return machineInfoService.addMachineInfo(machineInfoDto) ? ResponseData.success() : ResponseData.error("新增失败");
    }


    @GetMapping("/list")
    @Operation(summary = "获取机器信息列表")
    public ResponseData list(@RequestBody MachineInfoDto machineInfoDto) {
        return SuccessResponseData.success(machineInfoService.listMachineInfo(machineInfoDto));
    }

    @PutMapping("/update")
    @Operation(summary = "编辑机器信息")
    public ResponseData update(@RequestBody MachineInfoDto machineInfoDto) {
        return machineInfoService.updateMachineInfo(machineInfoDto) ? ResponseData.success() : ResponseData.error("更新失败");
    }

    @PutMapping("/updateStatus")
    @Operation(summary = "机器启用/停用")
    public ResponseData updateStatus(@RequestParam("machineInfoId") Long machineInfoId, @RequestParam("status") String status) {
        return machineInfoService.updateStatus(machineInfoId, status) ? ResponseData.success() : ResponseData.error("更新状态失败");
    }

    @PutMapping("/bindingSecretKey")
    @Operation(summary = "绑定密钥")
    public ResponseData bindingSecretKey(@RequestParam("machineInfoId") Long machineInfoId, @RequestParam("secretKeyId") Long secretKeyId) {
        return machineInfoService.bindingSecretKey(machineInfoId, secretKeyId) ? ResponseData.success() : ResponseData.error("绑定失败");
    }

    @DeleteMapping("/delete")
    @Operation(summary = "机器信息删除")
    public ResponseData delete(@RequestParam("machineInfoId") Long machineInfoId) {
        machineInfoService.deleteMachineInfo(machineInfoId);
        return ResponseData.success();
    }

    @DeleteMapping("/deleteList")
    @Operation(summary = "批量删除机器信息")
    public ResponseData deleteList(@RequestParam("machineInfoId") List<Long> machineInfoIds) {
        machineInfoService.deleteList(machineInfoIds);
        return ResponseData.success();
    }

    @PostMapping("/test")
    @Operation(summary = "测试机器连接")
    public ResponseData testConnection(@RequestBody MachineInfo machineInfo) {
        boolean result = machineInfoService.testConnection(machineInfo);
        return ResponseData.success();
    }

    @GetMapping("/status/{machineName}")
    @Operation(summary = "获取机器连接状态")
    public ResponseData getConnectionStatus(@PathVariable String machineName) {
        return ResponseData.success(machineInfoService.getConnectionStatus(machineName));
    }

    @GetMapping("/status/all")
    @Operation(summary = "获取所有机器连接状态")
    public ResponseData getAllConnectionStatus() {
       return ResponseData.success(machineInfoService.getAllConnectionStatus());
    }

    @PostMapping("/connect")
    @Operation(summary = "建立机器连接")
    public ResponseData connect(@RequestBody MachineInfo machineInfo) {
       return ResponseData.success(machineInfoService.connect(machineInfo));
    }

    @PostMapping("/disconnect/{sessionId}")
    @Operation(summary = "断开机器连接")
    public ResponseData disconnect(@PathVariable String sessionId) {
        return ResponseData.success(machineInfoService.disconnect(sessionId));
    }

    @PostMapping("/execute/{sessionId}")
    @Operation(summary = "执行远程命令")
    public ResponseData executeCommand(
            @PathVariable String sessionId,
            @RequestBody String command) {
       return ResponseData.success(machineInfoService.executeCommand(sessionId, command));
    }

    @PostMapping("/upload/{sessionId}")
    @Operation(summary = "上传文件到远程机器")
    public ResponseData uploadFile(
            @PathVariable String sessionId,
            @RequestParam String localFilePath,
            @RequestParam String remoteFilePath) {
        return ResponseData.success(machineInfoService.uploadFile(sessionId, localFilePath, remoteFilePath));
    }

    @PostMapping("/download/{sessionId}")
    @Operation(summary = "从远程机器下载文件")
    public ResponseData downloadFile(
            @PathVariable String sessionId,
            @RequestParam String remoteFilePath,
            @RequestParam String localFilePath) {
        return ResponseData.success(machineInfoService.downloadFile(sessionId, remoteFilePath, localFilePath));
    }
}
