package cd.casic.module.machine.controller;

import cd.casic.module.machine.service.MachineProxyService;
import cd.casic.module.machine.dto.MachineProxyDTO;
import cd.casic.module.machine.pojo.ResponseData;
import cd.casic.module.machine.pojo.SuccessResponseData;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 机器代理控制器
 */
@RestController
@RequestMapping("/api/machineProxy")
@Tag(name = "机器代理管理")
@RequiredArgsConstructor
public class MachineProxyController {

    @Resource
    private MachineProxyService machineProxyService;

    @PostMapping("/register")
    @Operation(summary ="注册新的机器代理")
    public ResponseData register(@RequestBody MachineProxyDTO machineProxyDTO) {
        return machineProxyService.register(machineProxyDTO) ? ResponseData.success() :ResponseData.error("注册新的机器代理失败");
    }

    @GetMapping("/list")
    @Operation(summary ="获取代理")
    public ResponseData list(MachineProxyDTO machineProxyDTO) {
        return ResponseData.success(machineProxyService.list(machineProxyDTO));
    }

    @PutMapping("/updateStatus")
    @Operation(summary ="更新代理状态")
    public ResponseData updateStatus(@RequestBody MachineProxyDTO machineProxyDTO) {
        return machineProxyService.updateStatus(machineProxyDTO) ? ResponseData.success() : ResponseData.error("更新代理状态失败");
    }

    @PostMapping("/receiptHeartbeat")
    @Operation(summary ="接收代理心跳")
    public ResponseData heartbeat(@RequestBody MachineProxyDTO machineProxyDTO) {
        return machineProxyService.heartbeat(machineProxyDTO) ? ResponseData.success() :ResponseData.error("接收代理心跳失败");
    }

    @GetMapping("/statistics/status")
    @Operation(summary ="获取所有代理的状态统计")
    public ResponseData getStatusStatistics() {
        return ResponseData.success(machineProxyService.getStatusStatistics());
    }

    @PutMapping("/updateConfig")
    @Operation(summary ="更新代理配置")
    public ResponseData updateConfig(@RequestBody MachineProxyDTO machineProxyDTO) {
        return machineProxyService.updateConfig(machineProxyDTO) ? ResponseData.success() : ResponseData.error("更新代理配置失败");
    }

    @DeleteMapping("/batch")
    @Operation(summary ="批量删除代理")
    public ResponseData deleteBatch(@RequestBody List<Long> ids) {
        machineProxyService.delete(ids);
        return new SuccessResponseData();
    }

}
