package cd.casic.module.machine.controller;


import cd.casic.module.machine.service.SecretKeyService;
import cd.casic.module.machine.dto.SecretKeyDto;
import cd.casic.module.machine.pojo.ResponseData;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@RestController
@RequestMapping("/api/secretKey")
@Tag(name =  "密钥管理")
public class SecretKeyController {
    @Resource
    private SecretKeyService secretKeyService;

    @PostMapping(value = "/add", consumes = "multipart/form-data")
    @Operation(summary ="新增密钥")
    public ResponseData add(@RequestPart("secretKeyDto") SecretKeyDto secretKeyDto, @RequestPart("file") MultipartFile file) {
        return secretKeyService.addSecretKey(secretKeyDto, file) ? ResponseData.success() : ResponseData.error("新增密钥失败");
    }

    @PutMapping("/bindingMachine")
    @Operation(summary ="绑定机器")
    public ResponseData bindingMachine(@RequestParam("secretKeyId") Long secretKeyId, @RequestParam("machineInfoIds") List<Long> machineInfoIds) {
        secretKeyService.bindingMachine(secretKeyId, machineInfoIds);
        return ResponseData.success();
    }

    @PutMapping("/update")
    @Operation(summary ="编辑密钥信息")
    public ResponseData update(@RequestPart("secretKeyDto") SecretKeyDto secretKeyDto, @RequestPart(value = "file", required = false) MultipartFile file) {
        return secretKeyService.updateSecretKey(secretKeyDto, file) ? ResponseData.success() : ResponseData.error("编辑密钥信息失败");
    }


    @DeleteMapping("/delete")
    @Operation(summary ="删除密钥")
    public ResponseData delete(@RequestParam("secretKeyId") Long secretKeyId) {
        return secretKeyService.deleteSecretKey(secretKeyId) ? ResponseData.success() : ResponseData.error("删除密钥");
    }

    @DeleteMapping("/deleteList")
    @Operation(summary ="批量删除密钥")
    public ResponseData deleteList(@RequestParam("secretKeyId") List<Long> secretKeyIds) {
        return secretKeyService.deleteList(secretKeyIds) ? ResponseData.success() : ResponseData.error("批量删除密钥");
    }

    @GetMapping("/list")
    @Operation(summary ="获取密钥信息列表")
    public ResponseData list(@RequestBody SecretKeyDto secretKeyDto) {
        return ResponseData.success(secretKeyService.listSecretKey(secretKeyDto));
    }

    @GetMapping("/downloadSecretKeyFile")
    @Operation(summary ="下载密钥文件")
    public ResponseEntity<InputStreamResource> downloadSecretKeyFile(@RequestParam("secretKeyId") Long secretKeyId) {
        return secretKeyService.downloadSecretKeyFile(secretKeyId);
    }
}
